#
# spec file for package python-validators
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-validators
Version:        0.34.0
Release:        1.2
Summary:        Python Data Validation
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/kvesteri/validators
Source:         https://files.pythonhosted.org/packages/source/v/validators/validators-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Python Data Validation for Humans.

%prep
%setup -q -n validators-%{version}
dos2unix README.md

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# missing eth-hash dependency so those tests must be skipped
%pytest -k 'not test_returns_true_on_valid_eth_address and not test_returns_failed_validation_on_invalid_eth_address'

%files %{python_files}
%doc README.md
%license LICENSE.txt
%{python_sitelib}/validators*

%changelog
* Sun Sep  8 2024 Dirk Müller <dmueller@suse.com>
- update to 0.34.0:
  * > No breaking changes were introduced in this version.
  * feat: cache IANA TLDs for faster lookups
  * chore: update dependencies
  * docs: adds configuration info
* Mon Jul 15 2024 Mia Herkt <mia@0x0.st>
- Update to 0.33.0
  Features:
  * add validator for bsc addresses
    gh#python-validators/validators#389
* Fri Jul 12 2024 Mia Herkt <mia@0x0.st>
- Update to 0.32.0
  Features:
  * add validator for sha384 hash
    gh#python-validators/validators#387
* Tue Jul  9 2024 Mia Herkt <mia@0x0.st>
- Update to 0.31.0
  Features:
  * add validators for base16 and base32 encodings
    gh#kvesteri/validators#386
* Thu Jul  4 2024 Mia Herkt <mia@0x0.st>
- Update to 0.30.0
  Features:
  * add validator for trx_addresses
    gh#kvesteri/validators#384
* Mon Jul  1 2024 Mia Herkt <mia@0x0.st>
- Update to 0.29.0
  Breaking:
  * move btc_address to crypto_addresses
    gh#kvesteri/validators#383
  Features:
  * add validator for eth addresses
    (depends on eth-hash, which is not packaged yet)
    gh#kvesteri/validators#383
* Sat May 25 2024 Mia Herkt <mia@0x0.st>
- Update to 0.28.3
  * ensure _tld.txt is in sdist and bdist
    gh#kvesteri/validators#379
- Changes in 0.28.2:
  * fix: corrects a few typo
    gh#kvesteri/validators#371
  * fix(ip_address): properly handle private is false
    gh#kvesteri/validators#374
  * chore(url): allow symbols and pictographs in url
    gh#kvesteri/validators#375
* Thu Apr 25 2024 Mia Herkt <mia@0x0.st>
- Update to 0.28.1
  * fix: reduce memory footprint when loading TLDs
    gh#kvesteri/validators#362
  * fix: rfc cases in the domain validator
    gh#kvesteri/validators#367
  * chore: documentation maintenance
    gh#kvesteri/validators#368
* Wed Apr 10 2024 Mia Herkt <mia@0x0.st>
- Update to 0.28.0
  See https://github.com/python-validators/validators/compare/0.24.0...0.28.0
* Thu Mar 28 2024 Mia Herkt <mia@0x0.st>
- Update to 0.24.0
  See https://github.com/python-validators/validators/compare/0.22.0...0.24.0
* Tue Nov  7 2023 Mia Herkt <mia@0x0.st>
- Update to 0.22.0
  See https://github.com/python-validators/validators/compare/0.20.0...0.22.0
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Fri Mar 17 2023 pgajdos@suse.com
- python-six is not required
* Wed Jun 15 2022 Mia Herkt <mia@0x0.st>
- Update to 0.20.0
  * Add ipv4 digit lenghts validation
    (gh#kvesteri/validators#191)
  * Fix error with international URLs that have more than 2 hyphens
    (gh#kvesteri/validators#184)
  Changes in 0.19.0:
  * Improve IPv6 validation
    (gh#kvesteri/validators#201 gh#kvesteri/validators#107)
  * Drop support for Python 3.4
* Sun Oct 11 2020 Mia Herkt <mia@0x0.st>
- Update to 0.18.1:
  * Made uuid validator accept UUID objects
* Thu Aug 20 2020 Mia Herkt <mia@0x0.st>
- Update to 0.18.0:
  * Added bitcoin address validator
  Changes from 0.17.0 to 0.17.1:
  * Fixed python_requires using twine
  Changes from 0.16.0 to 0.17.0:
  * Fix URL validator ip_last_octet regex
* Thu Jul 16 2020 Mia Herkt <mia@0x0.st>
- Update to 0.16.0:
  * Added support for emojis and more IDNA URLs
* Sat Jul 11 2020 Benjamin Greiner <code@bnavigator.de>
- remove isort build requirement. It is not called.
* Fri May  8 2020 Mia Herkt <mia@0x0.st>
- Update to 0.15.0:
  * Added bank card validators
- Changes for 0.14.3:
  * Handle None values gracefully in domain validator
  * Local part of the email address should be less or equal than
    64 bytes
  * Removed py27 support
  * Removed pypy2 support
* Fri Jan 24 2020 Martin Herkt <9+suse@cirno.systems>
- Update to 0.14.2:
  * Made domain validation case-insensitive
* Thu Dec  5 2019 Martin Herkt <9+suse@cirno.systems>
- Update to 0.14.1:
  * Updated domain validator regex to not allow numeric only TLDs
  * Allow for idna encoded domains
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.14.0:
  * Added new validators ipv4_cidr, ipv6_cidr
* Fri May 24 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.13.0:
  * Added new validator: es_doi, es_nif, es_cif, es_nie (#121, pull request courtesy kingbuzzman)
* Wed May 22 2019 pgajdos@suse.com
- version update to 0.12.6
  * Fixed domain validator for single character domains
    CVE-2019-19588 - boo#1158542
* Tue Apr 16 2019 Martin Herkt <9+suse@cirno.systems>
- Update to 0.12.5
  * Fixed py37 support
* Fri Mar 29 2019 pgajdos@suse.com
- version update to 0.12.4
  * Use inspect.getfullargspec() in py3
  * Added `allow_temporal_ssn` parameter to fi_ssn validator
  * Remove py33 support
  * Fixed IPv4 formatted IP address returning True on ipv6
  * Fixed IPv6 address parsing
  * Fixed domain validator for international domains and certain
    edge cases
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu May 24 2018 toddrme2178@gmail.com
- Run tests
- Spec file cleanups
* Tue Jan 30 2018 9+suse@cirno.systems
- Update to 0.12.1
  * Fixed IDNA encoded TLDs in domain validator
  * Fixed URL validator for URLs with invalid characters in
    userinfo part
- Use %%license macro
- Remove superfluous service
* Fri Oct 27 2017 9@cirno.systems
- Convert package to singlespec
- Add download _service
- Update to 0.12.0
  * 0.8.0 (2015-06-24)
    + Added new validator: iban
  * 0.9.0 (2015-10-10)
    + Added new validator: domain
  * 0.10.0 (2016-01-09)
    + Added support for internationalized domain names in
    domain validator
  * 0.10.1 (2016-04-09)
    + Fixed domain name validation for numeric domain names
    + Fixed IBAN validation for Norwegian and Belgian IBANs
  * 0.10.2 (2016-06-11)
    + Fixed various URL validation issues
  * 0.10.3 (2016-06-13)
    + Added public parameter to url validator
  * 0.11.0 (2016-08-30)
    + Fixed public url validation
    + Made URL validator case insensitive
    + Drop Python 2.6 support
  * 0.11.1 (2016-11-19)
    + Fixed pyp2rpm build problem
  * 0.11.2 (2017-01-08)
    + Fixed URL validator for urls with query parameters but
    without path
  * 0.11.3 (2017-03-27)
    + Fixed URL validator for URLs containing localhost
  * 0.12.0 (2017-06-03)
    + Added hash validators for md5, sha1, sha224, sha256
    and sha512
    + Made ipv6 validator support IPv4-mapped IPv6 addresses
* Mon Apr  6 2015 prusnak@opensuse.org
- created package (version 0.7)
